import sys
import inspect
import argparse
import logging

import argcomplete

import mini_buildd.misc
import mini_buildd.net
import mini_buildd.config

LOG = logging.getLogger(__name__)


class CLI():
    def __init__(self, prog, description, epilog=None):
        self.prog = prog
        mini_buildd.misc.setup_console_logging(logging.DEBUG)

        self.parser = argparse.ArgumentParser(prog=prog, description=description, epilog=epilog,
                                              formatter_class=mini_buildd.misc.ArgumentDefaultsRawTextHelpFormatter)
        self.parser.add_argument("--version", action="version", version=mini_buildd.__version__)
        self.parser.add_argument("-v", "--verbose", dest="verbosity", action="count", default=0,
                                 help="increase log level. Give twice for max logs")
        self.parser.add_argument("-q", "--quiet", dest="terseness", action="count", default=0,
                                 help="decrease log level. Give twice for min logs")
        self.args = None

    @classmethod
    def _add_endpoint(cls, parser):
        parser.add_argument("endpoint", action="store",
                            metavar="ENDPOINT",
                            help=f"HTTP target endpoint: {inspect.getdoc(mini_buildd.net.ClientEndpoint)}").completer = lambda **kwargs: mini_buildd.misc.DputCf().urls()

    @classmethod
    def _add_subparser(cls, subparser, cmd, doc):
        return subparser.add_parser(cmd, help=doc, formatter_class=mini_buildd.misc.ArgumentDefaultsRawTextHelpFormatter)

    def setup(self):
        pass

    def run(self):
        argcomplete.autocomplete(self.parser)
        self.args = self.parser.parse_args()
        LOG.setLevel(logging.WARNING - (10 * (min(2, self.args.verbosity) - min(2, self.args.terseness))))

        if LOG.getEffectiveLevel() <= logging.DEBUG:
            mini_buildd.config.DEBUG = ["exception"]

        try:
            self.setup()
            self.runcli()
        except BaseException as e:
            mini_buildd.config.log_exception(LOG, f"{self.prog} failed (try '-vv' to debug)", e)
            sys.exit(1)
